# Security Policy

## Supported Versions

The following versions of `hyh` are currently being supported with security updates.

| Version | Supported |
| ------- | --------- |
| 0.1.x   | ✅ Yes    |
| < 0.1   | ❌ No     |

## Reporting a Vulnerability

We take the security of `hyh` seriously. If you believe you have found a security vulnerability, please report it to us by emailing <security@10xengs.com>.

Please include:

- A description of the vulnerability.
- Steps to reproduce the issue.
- Potential impact.

We will acknowledge receipt of your report within 48 hours and provide a timeline for a fix.

Please do not report security vulnerabilities through public GitHub issues.
